<!-- docs/_sidebar.md -->

- [Home](/)
- [Features](features.md)
- [API](api.md)
- [Architecture](architecture.md)
- [Comparison](comparison.md)
- [Plugins](plugins.md)
- [Future Roadmap](roadmap.md)
- [Sponsors](sponsors.md)

